window.Gleam.initSearch([{"doc":"gleojson","title":"gleojson","content":"# gleojson\n\n[![Package Version](https://img.shields.io/hexpm/v/gleojson)](https://hex.pm/packages/gleojson)\n[![Hex Docs](https://img.shields.io/badge/hex-docs-ffaff3)](https://hexdocs.pm/gleojson/)\n\n**gleojson** is a GeoJSON parsing and encoding library for Gleam, following the [RFC 7946](https://tools.ietf.org/html/rfc7946) specification. It provides types and utility functions to encode and decode GeoJSON objects such as Points, LineStrings, Polygons, and more.\n\n## Installation\n\nAdd **gleojson** to your Gleam project:\n\n```sh\ngleam add gleojson\n```\n\n## Usage\n\n```gleam\npub fn main() {\n  let json_string = &quot;{\n    \\&quot;type\\&quot;: \\&quot;Feature\\&quot;,\n    \\&quot;geometry\\&quot;: {\n    \\&quot;type\\&quot;: \\&quot;Point\\&quot;,\n    \\&quot;coordinates\\&quot;: [125.6, 10.1]\n    },\n    \\&quot;properties\\&quot;: {\n    \\&quot;name\\&quot;: \\&quot;Dinagat Islands\\&quot;\n    }\n  }&quot;\n  // Decode the JSON string into a GeoJSON object\n  let result = json.decode(from: json_string, using: gleojson.geojson_decoder)\n  case result {\n    Ok(geojson) -&gt; {\n      // Successfully decoded GeoJSON\n      let encoded = gleojson.encode_geojson(geojson)\n      // encoded is now a Dynamic representation of the GeoJSON object\n      // You can use it for further processing or encoding back to JSON\n    }\n    Error(errors) -&gt; {\n      todo\n      // Handle decoding errors\n      // errors contains information about what went wrong during decoding\n    }\n  }\n}\n```\n\nFurther documentation can be found at https://hexdocs.pm/gleojson.\n\n## Development\n\n```\ngleam build\ngleam test\n```\n","url":"index.html"},{"doc":"gleojson","title":"Feature","content":"pub type Feature {\n  Feature(\n    geometry: option.Option(Geometry),\n    properties: option.Option(dict.Dict(String, dynamic.Dynamic)),\n    id: option.Option(dynamic.Dynamic),\n  )\n}\n A feature in a GeoJSON object.\nFeature(\n  geometry: option.Option(Geometry),\n  properties: option.Option(dict.Dict(String, dynamic.Dynamic)),\n  id: option.Option(dynamic.Dynamic),\n)\n\n\nSynonyms:\ngleojson.Feature\ngleojson Feature","url":"gleojson.html#Feature"},{"doc":"gleojson","title":"FeatureCollection","content":"pub type FeatureCollection {\n  FeatureCollection(features: List(Feature))\n}\n A collection of features in a GeoJSON object.\nFeatureCollection(features: List(Feature))\n\n\nSynonyms:\ngleojson.FeatureCollection\ngleojson FeatureCollection","url":"gleojson.html#FeatureCollection"},{"doc":"gleojson","title":"GeoJSON","content":"pub type GeoJSON {\n  GeoJSONGeometry(Geometry)\n  GeoJSONFeature(Feature)\n  GeoJSONFeatureCollection(FeatureCollection)\n}\n A GeoJSON object.\nGeoJSONGeometry(Geometry)\n\n\nGeoJSONFeature(Feature)\n\n\nGeoJSONFeatureCollection(FeatureCollection)\n\n\nSynonyms:\ngleojson.GeoJSON\ngleojson GeoJSON","url":"gleojson.html#GeoJSON"},{"doc":"gleojson","title":"Geometry","content":"pub type Geometry {\n  GeometryPoint(Point)\n  GeometryMultiPoint(MultiPoint)\n  GeometryLineString(LineString)\n  GeometryMultiLineString(MultiLineString)\n  GeometryPolygon(Polygon)\n  GeometryMultiPolygon(MultiPolygon)\n  GeometryCollectionType(GeometryCollection)\n}\n A geometry in a GeoJSON object.\nGeometryPoint(Point)\n\n\nGeometryMultiPoint(MultiPoint)\n\n\nGeometryLineString(LineString)\n\n\nGeometryMultiLineString(MultiLineString)\n\n\nGeometryPolygon(Polygon)\n\n\nGeometryMultiPolygon(MultiPolygon)\n\n\nGeometryCollectionType(GeometryCollection)\n\n\nSynonyms:\ngleojson.Geometry\ngleojson Geometry","url":"gleojson.html#Geometry"},{"doc":"gleojson","title":"GeometryCollection","content":"pub type GeometryCollection {\n  GeometryCollection(geometries: List(Geometry))\n}\n A collection of geometries in a GeoJSON object.\nGeometryCollection(geometries: List(Geometry))\n\n\nSynonyms:\ngleojson.GeometryCollection\ngleojson GeometryCollection","url":"gleojson.html#GeometryCollection"},{"doc":"gleojson","title":"LineString","content":"pub type LineString {\n  LineString(coordinates: List(Position))\n}\n A line string in a GeoJSON object.\nLineString(coordinates: List(Position))\n\n\nSynonyms:\ngleojson.LineString\ngleojson LineString","url":"gleojson.html#LineString"},{"doc":"gleojson","title":"MultiLineString","content":"pub type MultiLineString {\n  MultiLineString(coordinates: List(List(Position)))\n}\n A multi-line string in a GeoJSON object.\nMultiLineString(coordinates: List(List(Position)))\n\n\nSynonyms:\ngleojson.MultiLineString\ngleojson MultiLineString","url":"gleojson.html#MultiLineString"},{"doc":"gleojson","title":"MultiPoint","content":"pub type MultiPoint {\n  MultiPoint(coordinates: List(Position))\n}\n A multi-point in a GeoJSON object.\nMultiPoint(coordinates: List(Position))\n\n\nSynonyms:\ngleojson.MultiPoint\ngleojson MultiPoint","url":"gleojson.html#MultiPoint"},{"doc":"gleojson","title":"MultiPolygon","content":"pub type MultiPolygon {\n  MultiPolygon(coordinates: List(List(List(Position))))\n}\n A multi-polygon in a GeoJSON object.\nMultiPolygon(coordinates: List(List(List(Position))))\n\n\nSynonyms:\ngleojson.MultiPolygon\ngleojson MultiPolygon","url":"gleojson.html#MultiPolygon"},{"doc":"gleojson","title":"Point","content":"pub type Point {\n  Point(coordinates: Position)\n}\n A point in a GeoJSON object.\nPoint(coordinates: Position)\n\n\nSynonyms:\ngleojson.Point\ngleojson Point","url":"gleojson.html#Point"},{"doc":"gleojson","title":"Polygon","content":"pub type Polygon {\n  Polygon(coordinates: List(List(Position)))\n}\n A polygon in a GeoJSON object.\nPolygon(coordinates: List(List(Position)))\n\n\nSynonyms:\ngleojson.Polygon\ngleojson Polygon","url":"gleojson.html#Polygon"},{"doc":"gleojson","title":"Position","content":"pub type Position =\n  List(Float)\n A position in a GeoJSON object.\n\nSynonyms:\ngleojson.Position\ngleojson Position","url":"gleojson.html#Position"},{"doc":"gleojson","title":"encode_feature","content":"pub fn encode_feature(feature: Feature) -&gt; Dynamic\n Encodes a feature into a dynamic value.\nSynonyms:\ngleojson.encode_feature\ngleojson encode_feature","url":"gleojson.html#encode_feature"},{"doc":"gleojson","title":"encode_featurecollection","content":"pub fn encode_featurecollection(\n  collection: FeatureCollection,\n) -&gt; Dynamic\n Encodes a feature collection into a dynamic value.\nSynonyms:\ngleojson.encode_featurecollection\ngleojson encode_featurecollection","url":"gleojson.html#encode_featurecollection"},{"doc":"gleojson","title":"encode_geojson","content":"pub fn encode_geojson(geojson: GeoJSON) -&gt; Dynamic\n Encodes a GeoJSON object into a dynamic value.\nSynonyms:\ngleojson.encode_geojson\ngleojson encode_geojson","url":"gleojson.html#encode_geojson"},{"doc":"gleojson","title":"encode_geometry","content":"pub fn encode_geometry(geometry: Geometry) -&gt; Dynamic\n Encodes a geometry into a dynamic value.\nSynonyms:\ngleojson.encode_geometry\ngleojson encode_geometry","url":"gleojson.html#encode_geometry"},{"doc":"gleojson","title":"encode_geometrycollection","content":"pub fn encode_geometrycollection(\n  collection: GeometryCollection,\n) -&gt; Dynamic\n Encodes a geometry collection into a dynamic value.\nSynonyms:\ngleojson.encode_geometrycollection\ngleojson encode_geometrycollection","url":"gleojson.html#encode_geometrycollection"},{"doc":"gleojson","title":"encode_linestring","content":"pub fn encode_linestring(linestring: LineString) -&gt; Dynamic\n Encodes a line string into a dynamic value.\nSynonyms:\ngleojson.encode_linestring\ngleojson encode_linestring","url":"gleojson.html#encode_linestring"},{"doc":"gleojson","title":"encode_multilinestring","content":"pub fn encode_multilinestring(\n  multilinestring: MultiLineString,\n) -&gt; Dynamic\n Encodes a multi-line string into a dynamic value.\nSynonyms:\ngleojson.encode_multilinestring\ngleojson encode_multilinestring","url":"gleojson.html#encode_multilinestring"},{"doc":"gleojson","title":"encode_multipoint","content":"pub fn encode_multipoint(multipoint: MultiPoint) -&gt; Dynamic\n Encodes a multi-point into a dynamic value.\nSynonyms:\ngleojson.encode_multipoint\ngleojson encode_multipoint","url":"gleojson.html#encode_multipoint"},{"doc":"gleojson","title":"encode_multipolygon","content":"pub fn encode_multipolygon(multipolygon: MultiPolygon) -&gt; Dynamic\n Encodes a multi-polygon into a dynamic value.\nSynonyms:\ngleojson.encode_multipolygon\ngleojson encode_multipolygon","url":"gleojson.html#encode_multipolygon"},{"doc":"gleojson","title":"encode_point","content":"pub fn encode_point(point: Point) -&gt; Dynamic\n Encodes a point into a dynamic value.\nSynonyms:\ngleojson.encode_point\ngleojson encode_point","url":"gleojson.html#encode_point"},{"doc":"gleojson","title":"encode_polygon","content":"pub fn encode_polygon(polygon: Polygon) -&gt; Dynamic\n Encodes a polygon into a dynamic value.\nSynonyms:\ngleojson.encode_polygon\ngleojson encode_polygon","url":"gleojson.html#encode_polygon"},{"doc":"gleojson","title":"encode_position","content":"pub fn encode_position(position: List(Float)) -&gt; Dynamic\n Encodes a position into a dynamic value.\nSynonyms:\ngleojson.encode_position\ngleojson encode_position","url":"gleojson.html#encode_position"},{"doc":"gleojson","title":"encode_positions","content":"pub fn encode_positions(positions: List(List(Float))) -&gt; Dynamic\n Encodes a list of positions into a dynamic value.\nSynonyms:\ngleojson.encode_positions\ngleojson encode_positions","url":"gleojson.html#encode_positions"},{"doc":"gleojson","title":"encode_positions_list","content":"pub fn encode_positions_list(\n  positions_list: List(List(List(Float))),\n) -&gt; Dynamic\n Encodes a list of positions into a dynamic value.\nSynonyms:\ngleojson.encode_positions_list\ngleojson encode_positions_list","url":"gleojson.html#encode_positions_list"},{"doc":"gleojson","title":"encode_positions_list_list","content":"pub fn encode_positions_list_list(\n  positions_list_list: List(List(List(List(Float)))),\n) -&gt; Dynamic\n Encodes a list of lists of positions into a dynamic value.\nSynonyms:\ngleojson.encode_positions_list_list\ngleojson encode_positions_list_list","url":"gleojson.html#encode_positions_list_list"},{"doc":"gleojson","title":"feature_decoder","content":"pub fn feature_decoder(\n  dynamic_value: Dynamic,\n) -&gt; Result(Feature, List(DecodeError))\n Decodes a feature from a dynamic value.\nSynonyms:\ngleojson.feature_decoder\ngleojson feature_decoder","url":"gleojson.html#feature_decoder"},{"doc":"gleojson","title":"featurecollection_decoder","content":"pub fn featurecollection_decoder(\n  dynamic_value: Dynamic,\n) -&gt; Result(FeatureCollection, List(DecodeError))\n Decodes a feature collection from a dynamic value.\nSynonyms:\ngleojson.featurecollection_decoder\ngleojson featurecollection_decoder","url":"gleojson.html#featurecollection_decoder"},{"doc":"gleojson","title":"geojson_decoder","content":"pub fn geojson_decoder(\n  dynamic_value: Dynamic,\n) -&gt; Result(GeoJSON, List(DecodeError))\n Decodes a GeoJSON object from a dynamic value.\nSynonyms:\ngleojson.geojson_decoder\ngleojson geojson_decoder","url":"gleojson.html#geojson_decoder"},{"doc":"gleojson","title":"geometry_decoder","content":"pub fn geometry_decoder(\n  dynamic_value: Dynamic,\n) -&gt; Result(Geometry, List(DecodeError))\n Decodes a geometry from a dynamic value.\nSynonyms:\ngleojson.geometry_decoder\ngleojson geometry_decoder","url":"gleojson.html#geometry_decoder"},{"doc":"gleojson","title":"geometrycollection_decoder","content":"pub fn geometrycollection_decoder(\n  dynamic_value: Dynamic,\n) -&gt; Result(GeometryCollection, List(DecodeError))\n Decodes a geometry collection from a dynamic value.\nSynonyms:\ngleojson.geometrycollection_decoder\ngleojson geometrycollection_decoder","url":"gleojson.html#geometrycollection_decoder"},{"doc":"gleojson","title":"linestring_decoder","content":"pub fn linestring_decoder(\n  dynamic_value: Dynamic,\n) -&gt; Result(LineString, List(DecodeError))\n Decodes a line string from a dynamic value.\nSynonyms:\ngleojson.linestring_decoder\ngleojson linestring_decoder","url":"gleojson.html#linestring_decoder"},{"doc":"gleojson","title":"multilinestring_decoder","content":"pub fn multilinestring_decoder(\n  dynamic_value: Dynamic,\n) -&gt; Result(MultiLineString, List(DecodeError))\n Decodes a multi-line string from a dynamic value.\nSynonyms:\ngleojson.multilinestring_decoder\ngleojson multilinestring_decoder","url":"gleojson.html#multilinestring_decoder"},{"doc":"gleojson","title":"multipoint_decoder","content":"pub fn multipoint_decoder(\n  dynamic_value: Dynamic,\n) -&gt; Result(MultiPoint, List(DecodeError))\n Decodes a multi-point from a dynamic value.\nSynonyms:\ngleojson.multipoint_decoder\ngleojson multipoint_decoder","url":"gleojson.html#multipoint_decoder"},{"doc":"gleojson","title":"multipolygon_decoder","content":"pub fn multipolygon_decoder(\n  dynamic_value: Dynamic,\n) -&gt; Result(MultiPolygon, List(DecodeError))\n Decodes a multi-polygon from a dynamic value.\nSynonyms:\ngleojson.multipolygon_decoder\ngleojson multipolygon_decoder","url":"gleojson.html#multipolygon_decoder"},{"doc":"gleojson","title":"point_decoder","content":"pub fn point_decoder(\n  dynamic_value: Dynamic,\n) -&gt; Result(Point, List(DecodeError))\n Decodes a point from a dynamic value.\nSynonyms:\ngleojson.point_decoder\ngleojson point_decoder","url":"gleojson.html#point_decoder"},{"doc":"gleojson","title":"polygon_decoder","content":"pub fn polygon_decoder(\n  dynamic_value: Dynamic,\n) -&gt; Result(Polygon, List(DecodeError))\n Decodes a polygon from a dynamic value.\nSynonyms:\ngleojson.polygon_decoder\ngleojson polygon_decoder","url":"gleojson.html#polygon_decoder"},{"doc":"gleojson","title":"position_decoder","content":"pub fn position_decoder(\n  dynamic_value: Dynamic,\n) -&gt; Result(List(Float), List(DecodeError))\n Decodes a position from a dynamic value.\nSynonyms:\ngleojson.position_decoder\ngleojson position_decoder","url":"gleojson.html#position_decoder"},{"doc":"gleojson","title":"positions_decoder","content":"pub fn positions_decoder(\n  dynamic_value: Dynamic,\n) -&gt; Result(List(List(Float)), List(DecodeError))\n Decodes a list of positions from a dynamic value.\nSynonyms:\ngleojson.positions_decoder\ngleojson positions_decoder","url":"gleojson.html#positions_decoder"},{"doc":"gleojson","title":"positions_list_decoder","content":"pub fn positions_list_decoder(\n  dynamic_value: Dynamic,\n) -&gt; Result(List(List(List(Float))), List(DecodeError))\n Decodes a list of lists of positions from a dynamic value.\nSynonyms:\ngleojson.positions_list_decoder\ngleojson positions_list_decoder","url":"gleojson.html#positions_list_decoder"},{"doc":"gleojson","title":"positions_list_list_decoder","content":"pub fn positions_list_list_decoder(\n  dynamic_value: Dynamic,\n) -&gt; Result(List(List(List(List(Float)))), List(DecodeError))\n Decodes a list of lists of lists of positions from a dynamic value.\nSynonyms:\ngleojson.positions_list_list_decoder\ngleojson positions_list_list_decoder","url":"gleojson.html#positions_list_list_decoder"},{"doc":"gleojson","title":"gleojson","content":" Functions for working with GeoJSON data.\n\n This module provides types and functions for encoding and decoding GeoJSON data.\n It supports all GeoJSON object types including Point, MultiPoint, LineString,\n MultiLineString, Polygon, MultiPolygon, GeometryCollection, Feature, and FeatureCollection.\n\n ## Usage\n\n To use this module, you can import it in your Gleam code:\n\n ```gleam\n import gleojson\n ```\n\n Then you can use the provided functions to encode and decode GeoJSON data.\n Types","url":"gleojson.html"}]);